@@ -53,7 +53,7 @@ class EMIOptionsResponseEnum(str, Enum):
 class ShippingMethodEnum(str, Enum):
     YES = "YES"
     NO = "NO"
-    COURIER = "COURIER"
+    COURIER = "Courier"
 
 
 class BooleanIntEnum(int, Enum):
@@ -414,15 +414,6 @@ class OrderStatusEnum(str, Enum):
     INVALID_TRANSACTION = "INVALID_TRANSACTION"
 
 
-class CardBrandEnum(str, Enum):
-    NONE = ""
-    VISA = "VISA"
-    MASTER = "MASTER"
-    AMEX = "AMEX"
-    IB = "IB"
-    MOBILE_BANKING = "MOBILE BANKING"
-
-
 class RiskLevelEnum(str, Enum):
     HIGH = "1"
     LOW = "0"
@@ -441,7 +432,7 @@ class BaseOrderResponse(BaseModel):
     currency: str
     bank_tran_id: str
     card_issuer: str
-    card_brand: CardBrandEnum
+    card_brand: str
     card_issuer_country: str
     card_issuer_country_code: str
     currency_type: str
@@ -613,7 +604,7 @@ class Session(BaseModel):
     card_no: str
     bank_tran_id: str
     card_issuer: str
-    card_brand: CardBrandEnum
+    card_brand: str
     card_issuer_country: str
     card_issuer_country_code: str
     currency_type: str
@@ -633,6 +624,7 @@ class Session(BaseModel):
     value_c: Optional[str]
     value_d: Optional[str]
 
+
 class TransactionBySessionResponse(Session):
     """Dataclass for transaction by session query."""
 
